@@ -25,7 +25,7 @@ from .config import encrypt, decrypt, get_config
 HEADER_FILE = """
 # WARNING: InfraSonar will make `password` and `secret` values unreadable but
 # this must not be regarded as true encryption as the encryption key is
-# publically available.
+# publicly available.
 #
 # Example configuration for `myprobe` collector:
 #
@@ -359,10 +359,6 @@ class Probe:
                 logging.warning(
                     'incomplete result; '
                     f'{asset} error: `{e}` severity: {e.severity}')
-                logging.error(path)
-                logging.error(e.result)
-                logging.error(e.to_dict())
-                logging.error(ts)
                 self.send(path, e.result, e.to_dict(), ts)
 
             except CheckException as e:
